@@ -360,3 +360,15 @@ is_acyclic <- function(object){
   object <- as_igraph(object)
   igraph::is_dag(object)
 }
+
+#' @describeIn is Tests whether there is a matching for a network
+#'   that covers every node in the network
+#' @param mark A logical vector marking two types or modes.
+#'   By default "type".
+#' @examples
+#' is_perfect_matching(ison_southern_women)
+#' @export
+is_perfect_matching <- function(object, mark = "type"){
+  matches <- to_matching(object, mark = mark)
+  network_ties(matches)*2 == network_nodes(matches)
+}
